@@ -3,11 +3,11 @@ import torch
 from torch.utils.data import DataLoader
 import sys, os
 sys.path.insert(0, os.path.join(
-    os.path.dirname(os.path.realpath(__file__)), "../"))
-from dataloading.dataloading import FeatureExtractorDataset
-from lib.training import test
-from utils.model_editing import drop_layers
-import bin.config
+    os.path.dirname(os.path.realpath(__file__)), "../../"))
+from deep_audio_features.dataloading.dataloading import FeatureExtractorDataset
+from deep_audio_features.lib.training import test
+from deep_audio_features.utils.model_editing import drop_layers
+import deep_audio_features.bin.config
 import numpy
 
 
